@@ -1,7 +1,7 @@
 # This file is part of Hypothesis, which may be found at
 # https://github.com/HypothesisWorks/hypothesis/
 #
-# Most of this work is copyright (C) 2013-2020 David R. MacIver
+# Most of this work is copyright (C) 2013-2021 David R. MacIver
 # (david@drmaciver.com), but it contains contributions by others. See
 # CONTRIBUTING.rst for a full list of people who may hold copyright, and
 # consult the git log if you need to determine who owns an individual
@@ -210,6 +210,7 @@ class SearchStrategy(Generic[Ex]):
     supports_find = True
     validate_called = False
     __label = None
+    __module__ = "hypothesis.strategies"
 
     def available(self, data):
         """Returns whether this strategy can *currently* draw any
@@ -728,7 +729,7 @@ class FilteredStrategy(SearchStrategy):
 
         data.note_event("Aborted test because unable to satisfy %r" % (self,))
         data.mark_invalid()
-        raise AssertionError("Unreachable, for Mypy")  # pragma: no cover
+        raise NotImplementedError("Unreachable, for Mypy")
 
     def note_retried(self, data):
         data.note_event(lazyformat("Retried draw from %r to satisfy filter", self))
